<?php

namespace EventPortal\AuthPassword\Http\Controllers;

use EventPortal\AuthPassword\Http\Requests\LoginRequest;
use Illuminate\Http\RedirectResponse;
use Illuminate\Routing\Controller;
use Inertia\Inertia;
use Inertia\Response;

class LoginController extends Controller
{
    public function index(): Response
    {
        return Inertia::render('Login/Password', [
            'field_names' => config('auth-password.field_names'),
        ]);
    }

    public function login(LoginRequest $request): RedirectResponse
    {
        $credentials = $request->only([
            config('auth-password.field_names.username'),
            config('auth-password.field_names.password'),
        ]);

        if (auth()->attempt($credentials)) {
            return redirect()->intended(route('admin.event.index'));
        }

        return redirect()->back()->withErrors([
            config('auth-password.field_names.password') => trans('auth.failed'),
        ]);
    }

    public function logout(): RedirectResponse
    {
        auth()->logout();

        return redirect()->route('login.index');
    }
}
